@@ -5,18 +5,13 @@ from datetime import datetime
 import numpy as np
 import pandas as pd
 import ray
-from ray.rllib.agents.ppo import PPOTrainer
-from ray.rllib.agents.ppo import APPOTrainer
-from ray.rllib.agents.ppo import DDPPOTrainer
-from ray.rllib.agents.dqn import DQNTrainer
-from ray.rllib.agents.dqn import ApexTrainer
-
+from lairningdecisions.utils.db import db_connect, TRAINER_DB_NAME, P_MARKER, select_record, SQLParamList, select_all
+from ray.rllib.agents.dqn import DQNTrainer, ApexTrainer
+from ray.rllib.agents.ppo import PPOTrainer, APPOTrainer, DDPPOTrainer
 from ray.tune import run as tune_run
 # from ray.tune import sample_from as tune_sample_from
 from ray.tune.schedulers import PopulationBasedTraining
 
-from lairningdecisions.utils.db import db_connect, TRAINER_DB_NAME, P_MARKER, select_record, SQLParamList, select_all
-
 TRAINERS = {'ppo': PPOTrainer, 'appo': APPOTrainer, 'ddpo': DDPPOTrainer, 'dqn': DQNTrainer, 'apex_dqn': ApexTrainer}
 
 from gym.spaces import Discrete
@@ -671,7 +666,6 @@ class AISimAgent:
             time_start = datetime.now()
             result_list = ray.get([base_run.remote(baseline) for _ in range(simulations)])
 
-
             policy_run_data = (sim_config_id, time_start, simulations,
                                (datetime.now() - time_start).total_seconds(), json.dumps(result_list))
             self._add_baseline_run(policy_run_data)
@@ -729,3 +723,36 @@ class AIDataAgent(AISimAgent):
     def __init__(self, sim_name: str, csv_name: str, test_percent: float = 0.3, log_level: str = "ERROR",
                  checkpoint_path=None, ai_config: dict = None, sim_config: dict = None):
         super().__init__("DATA", sim_name, log_level, checkpoint_path, ai_config, sim_config, csv_name, test_percent)
+
+
+import simpy
+
+
+class SimpyModel(simpy.Environment):
+    def __init__(self, base_config: dict, config: dict = None):
+        assert base_config is not None, "base_config cannot be None"
+        super().__init__()
+        self.sim_config = base_config.copy()
+        if config is not None:
+            self.sim_config.update(config)
+        self.time = self.now
+        assert {"SIM_DURATION", "ACTION_INTERVAL"} <= set(config.keys()), \
+            '{"SIM_DURATION", "ACTION_INTERVAL"} not defined'
+        self.sim_duration = config["SIM_DURATION"]
+        self.step_time = config["ACTION_INTERVAL"]
+
+    def run_until_action(self):
+        self.run(until=self.time + self.step_time)
+        self.time = self.now
+
+    def done(self):
+        return self.now >= self.sim_duration
+
+    def exec_action(self, action):
+        raise Exception("Not Implemented!!!")
+
+    def get_observation(self):
+        raise Exception("Not Implemented!!!")
+
+    def get_reward(self):
+        raise Exception("Not Implemented!!!")
